@@ -554,7 +554,7 @@ class Database(object):
 
     def querify(self, query,
                 language=None,
-                translit='translit/long',
+                translit=None,
                 default_op=Query.OP_AND,
                 parser_flags=default_parser_flags):
         """Return a query object, constructed from a string, query
@@ -594,7 +594,7 @@ class Database(object):
               reverse=False,
               language=None,
               check=0,
-              translit='translit/long',
+              translit=None,
               match_decider=None,
               match_spy=None,
               document=False,
@@ -632,7 +632,7 @@ class Database(object):
               query="",
               language=None,
               echo=False,
-              translit='translit/long',
+              translit=None,
               parser_flags=default_parser_flags,
               default_op=Query.OP_AND):
         """
@@ -688,7 +688,7 @@ class Database(object):
     def expand(self, query, expand,
                language=None,
                echo=False,
-               translit='translit/long',
+               translit=None,
                default_op=Query.OP_AND,
                parser_flags=default_parser_flags):
         """
@@ -696,6 +696,8 @@ class Database(object):
         """
 
         q = self.querify(query, language, translit, default_op, parser_flags)
+        if echo:
+            print q
         results = {}
         head, tail = expand[0], expand[1:]
         if isinstance(head, tuple):
@@ -712,6 +714,8 @@ class Database(object):
         for name, score in r:
             if tail:
                 subq = self.querify([q, name])
+                if echo:
+                    print subq
                 r = self.expand(
                     subq, tail, language, echo,
                     default_op, parser_flags)
@@ -724,7 +728,7 @@ class Database(object):
                  limit=0,
                  klimit=1.0,
                  language=None,
-                 translit='translit/long',
+                 translit=None,
                  check_at_least=None,
                  default_op=Query.OP_AND,
                  parser_flags=default_parser_flags):
@@ -786,7 +790,7 @@ class Database(object):
                 mlimit=0,
                 klimit=1.0,
                 kmlimit=1.0,
-                translit='translit/long',
+                translit=None,
                 language=None,
                 prefix=None,
                 decider=None,
